require "version"
require 'sinatra/cross_origin'
require 'rack/contrib'

module SinatraOnlyJSON
  class JSONStringify
    def initialize(app)
      @app = app
    end

    def call(env)
      status, headers, body = @app.call(env)
      if %w(GET PUT POST DELETE PATCH).index(env["REQUEST_METHOD"])
        return status, headers, [body.to_json]
      else
        return status, headers, body
      end
    end
  end

  def self.included(klass)
    # JSON Support
    klass.use Rack::PostBodyContentTypeParser
    klass.use JSONStringify
    klass.before { content_type :json }

    # CORS Support
    klass.register Sinatra::CrossOrigin
    klass.configure { klass.enable :cross_origin }
    klass.options "*" do
      response.headers["Allow"] = "HEAD,GET,PUT,POST,DELETE,OPTIONS"
      response.headers["Access-Control-Allow-Methods"] = "GET,PUT,POST,DELETE"
      response.headers["Access-Control-Allow-Headers"] = "X-Requested-With, X-HTTP-Method-Override, Content-Type, Cache-Control, Accept"
      200
    end
  end
end
